@@ -6,8 +6,10 @@ pub struct Site {
     pub url: String,
     pub name: String,
     pub logo: Option<String>,
-    pub title: String,
     pub description: Option<String>,
+    /// The locale to localize some builtin text.
+    /// Default to 'en'.
+    pub locale: Option<String>,
     #[serde(rename(deserialize = "menu"))]
     #[serde(default)]
     pub menus: Vec<Menu>,
